from th2_cli.utils import read_value, is_ip, write_file, print_info, print_used_value
from th2_cli.utils.kubernetes import connect, get_cluster_host, create_secret
from th2_cli.utils.cassandra import choose_datacenter
from th2_cli.utils.crypto import generate_ssh_keys
from th2_cli.utils.helm.charts_installer import ChartsInstaller
from th2_cli.utils.infra import install_flannel, create_namespace, choose_node, \
    apply_yaml, pv_folders_warning, preinstall_warning
from simple_term_menu import TerminalMenu
from th2_cli.templates.install import InstallTemplates

TH2_VERSION = '1.5.4'


def install():
    preinstall_warning()
    print_info('Connecting to the cluster...')
    k8s_client, k8s_core = connect()
    print_info("Preparing Kubernetes cluster...")
    # Install flannel
    install_flannel(k8s_client)
    # Create namespaces
    create_namespace(k8s_core, 'monitoring')
    create_namespace(k8s_core, 'service')
    # Apply PV's
    print('Please choose node for storing PersistentVolumes')
    node = choose_node(k8s_core)
    print_used_value('Node for PersistentVolumes storage', node)
    pv_folders_warning()
    print_info('Creating PV\'s and PVC\'s...')
    apply_yaml(k8s_client, InstallTemplates.pvs(node_name=node), 'pvs.yaml')
    apply_yaml(k8s_client, InstallTemplates.pvcs(), 'pvcs.yaml')
    # Get information about Kubernetes cluster
    cluster_host = get_cluster_host(k8s_client)
    print_used_value('Cluster host', cluster_host)
    if is_ip(cluster_host):
        cluster_hostname = read_value('Enter Kubernetes cluster hostname, if it exist.', 'hostname')
        print_used_value('Cluster hostname', cluster_hostname)
    else:
        cluster_hostname = ''
    # Get information about Cassandra database
    cassandra_host = read_value('Enter hostname of Cassandra to access it from the Kubernetes cluster', 'host', '127.0.0.1')
    print_used_value('Cassandra host', cassandra_host)
    dc_input_index = TerminalMenu(
        [
            'Enter datacenter manually',
            'Connect to Cassandra and choose available datacenter (Admin credentials required)'
        ],
        title='How do you want to specify Cassandra datacenter?'
    ).show()
    if dc_input_index == 0:
        cassandra_dc = read_value('Enter Cassandra datacenter name.', 'datacenter', 'datacenter1')
    else:
        cassandra_dc = choose_datacenter(cassandra_host)
    print_used_value('Cassandra datacenter', cassandra_dc)
    # Get information about infra-schema
    schema_link = read_value('Enter link to your infra-schema', 'link')
    print_used_value('th2-infra-schema link', schema_link)
    if schema_link.startswith('https://'):
        print_info('th2 will be authenticated in git by Personal Access Token (PAT)')
        token = read_value('Enter PAT for your infra-schema', 'PAT')
        print_used_value('Personal Access Token', token)
        create_secret(k8s_core, 'infra-mgr', namespace='service', string_data={'infra-mgr': 'infra-mgr'})
    else:
        token = None
        print_info('th2 will be authenticated in git by SSH key')
        private_key, public_key = generate_ssh_keys()
        write_file('infra-mgr-rsa.key', private_key)
        write_file('infra-mgr-rsa.key.pub', public_key)
        create_secret(k8s_core, 'infra-mgr', namespace='service', string_data={'infra-mgr': private_key})
    # Deploy infrastructure
    print_info('Deploying monitoring infrastructure...')
    charts_installer = ChartsInstaller(namespace='monitoring', th2_version=TH2_VERSION)
    charts_installer.add_helm_release('prometheus-community', 'kube-prometheus-stack',
                                      'https://prometheus-community.github.io/helm-charts', '15.0.0',
                                      InstallTemplates.prometheus_operator_values(hosts=cluster_hostname))
    charts_installer.add_helm_release('kubernetes-dashboard', 'kubernetes-dashboard',
                                      'https://kubernetes.github.io/dashboard/', '5.9.0',
                                      InstallTemplates.dashboard_values(hosts=cluster_hostname))
    charts_installer.add_helm_release('grafana', 'loki-stack',
                                      'https://grafana.github.io/helm-charts', '0.40.1',
                                      InstallTemplates.loki_values())
    charts_installer.install_charts()
    print_info('Deploying service infrastructure...')
    charts_installer = ChartsInstaller(namespace='service', th2_version=TH2_VERSION)
    charts_installer.add_helm_release('fluxcd', 'helm-operator',
                                      'https://charts.fluxcd.io', '1.2.0',
                                      InstallTemplates.helm_operator_values())
    charts_installer.add_helm_release('ingress-nginx', 'ingress-nginx',
                                      'https://kubernetes.github.io/ingress-nginx', '3.31.0',
                                      InstallTemplates.ingress_values())
    charts_installer.add_helm_release('th2', 'th2',
                                      'https://th2-net.github.io', '1.5.4',
                                      {
                                          **InstallTemplates.service_values(schema_link=schema_link,
                                                                            pat_token=token or '',
                                                                            cluster_host=cluster_hostname or cluster_host,
                                                                            cassandra_host=cassandra_host,
                                                                            cassandra_datacenter=cassandra_dc),
                                          **InstallTemplates.secrets()
                                      })
    charts_installer.install_charts()
    print_info(f'th2 {TH2_VERSION} is installed')







import yaml
from typing import Iterator

from th2_cli.templates.install.values.dashboard import yaml as dashboard_values_yaml
from th2_cli.templates.install.values.helm_operator import yaml as helm_operator_values_yaml
from th2_cli.templates.install.values.ingress import yaml as ingress_values_yaml
from th2_cli.templates.install.values.loki import yaml as loki_values_yaml
from th2_cli.templates.install.values.prometheus_operator import yaml as prometheus_operator_values_yaml
from th2_cli.templates.install.values.secrets import yaml as secrets_yaml
from th2_cli.templates.install.values.service import yaml as service_values_yaml
from th2_cli.templates.install.pvs import yaml as pvs_yaml
from th2_cli.templates.install.pvcs import yaml as pvcs_yaml


class InstallTemplates:
    @staticmethod
    def dashboard_values(hosts: str = '') -> dict:
        changed_template = dashboard_values_yaml \
            .replace('<hosts>', hosts)
        return yaml.safe_load(changed_template)

    @staticmethod
    def helm_operator_values() -> dict:
        changed_template = helm_operator_values_yaml
        return yaml.safe_load(changed_template)

    @staticmethod
    def ingress_values() -> dict:
        changed_template = ingress_values_yaml
        return yaml.safe_load(changed_template)

    @staticmethod
    def loki_values() -> dict:
        changed_template = loki_values_yaml
        return yaml.safe_load(changed_template)

    @staticmethod
    def prometheus_operator_values(hosts: str = '') -> dict:
        changed_template = prometheus_operator_values_yaml \
            .replace('<hosts>', hosts)
        return yaml.safe_load(changed_template)

    @staticmethod
    def secrets() -> dict:
        changed_template = secrets_yaml
        return yaml.safe_load(changed_template)

    @staticmethod
    def service_values(schema_link: str, pat_token: str = '',
                       cluster_host: str = '',
                       cassandra_host: str = '127.0.0.1', cassandra_datacenter: str = 'datacenter1') -> dict:
        changed_template = service_values_yaml\
            .replace('<repository>', schema_link)\
            .replace('<username>', pat_token)\
            .replace('<password>', pat_token)\
            .replace('<host>', cluster_host)\
            .replace('<cassandra-host>', cassandra_host)\
            .replace('<cassandra-dc>', cassandra_datacenter)
        return yaml.safe_load(changed_template)

    @staticmethod
    def pvs(node_name: str) -> Iterator[dict]:
        changed_template = pvs_yaml.replace('<node-name>', node_name)
        return yaml.safe_load_all(changed_template)

    @staticmethod
    def pvcs() -> Iterator[dict]:
        changed_template = pvcs_yaml
        return yaml.safe_load_all(changed_template)



import requests
import os
import yaml
from typing import Iterator
from colorama import Fore, Back, Style


def get_file(path: str) -> str:
    if path.startswith('http'):
        response = requests.get(path)
        response.close()
        content = response.content
    else:
        file_path = os.path.abspath(
            os.path.join(os.path.abspath(__file__), os.pardir, os.pardir, os.pardir, path)
        )
        file = open(file_path)
        content = file.read()
    return content


def get_yaml_config(path: str) -> Iterator[dict]:
    yaml_text = get_file(path)
    return yaml.safe_load_all(yaml_text)


def print_info(message):
    print(f'{Fore.BLUE}{message}{Style.RESET_ALL}')


def print_error(message):
    print(f'{Fore.RED}{message}{Style.RESET_ALL}')


def read_value(question: str, prompt: str = '', default_value: str = '') -> str:
    if bool(default_value):
        print(f'{question} {Style.DIM}(Default: "{default_value}"){Style.RESET_ALL}')
    else:
        print(question)
    value = input(f'{prompt}: {Fore.CYAN}')
    print(Style.RESET_ALL, end='\r')
    if not bool(value):
        value = default_value
    return value


def print_used_value(description: str, value: str):
    print(f'{description}: {Fore.GREEN}{value}{Style.RESET_ALL}')


def is_ip(address: str) -> bool:
    return address.replace('.', '').isnumeric()


def write_file(name: str, content: any):
    f = open(name, "w")
    f.write(content)
    f.close()



from avionix import ChartDependency, ChartBuilder, ChartInfo
from th2_cli.utils import print_error
import tempfile

class ChartsInstaller:

    def __init__(self, namespace: str, th2_version: str):
        self.namespace = namespace
        self.th2_version = th2_version
        self.chart_info = ChartInfo(
            api_version='v2',
            name=f'th2--{namespace}',
            version=th2_version
        )

    def add_helm_release(self, repo_name: str, chart_name: str, repo_url: str, version: str, values: dict = {}):
        self.chart_info.dependencies.append(ChartDependency(
            name=chart_name,
            version=version,
            repository=repo_url,
            local_repo_name=repo_name,
            values=values,
            is_local=False
        ))

    def install_charts(self):
        try:
            chart_builder = ChartBuilder(self.chart_info, [], output_directory=tempfile.gettempdir())
            chart_builder.install_chart({
                'namespace': self.namespace,
                "dependency-update": None
            })
        except:
            print_error(f'Deploying infrastructure into "{self.namespace}" was unsuccessful')




yaml = '''global:
  imagePullSecrets:
# alertmanager:
#   alertmanagerSpec:
#     # image:
#     #   repository: quay.io/prometheus/alertmanager
#     # externalUrl:
#   ingress:
#     enabled: true
#     annotations:
#       kubernetes.io/ingress.class: "nginx"
#       nginx.ingress.kubernetes.io/rewrite-target: /$1
#       nginx.ingress.kubernetes.io/use-regex: "true"
#     paths:
#     - /alertmanager/?(.*)
#     pathType: Prefix

prometheusOperator:
  # image: 
  #   repository: quay.io/prometheus-operator/prometheus-operator
  admissionWebhooks:
    enabled: false
    patch:
      enabled: false
  # prometheusConfigReloaderImage:
  #   repository: quay.io/prometheus-operator/prometheus-config-reloader
  tls:
    enabled: false

prometheus:
  prometheusSpec:
    # image:
    #   repository: quay.io/prometheus/prometheus
    # externalUrl: 
    storageSpec:
      volumeClaimTemplate:
        spec:
          selector:
            matchLabels:
              app: prometheus
          resources:
            requests:
              storage: 5Gi
  ingress:
    enabled: true
    annotations:
      kubernetes.io/ingress.class: "nginx"
      nginx.ingress.kubernetes.io/rewrite-target: /$1
      nginx.ingress.kubernetes.io/use-regex: "true"
    paths:
    - /prometheus/?(.*)
    pathType: Prefix

grafana:
  testFramework:
    enabled: false
  # image:
  #   repository: grafana/grafana
  #   pullSecrets:
  # sidecar:
  #   image:
  #     repository: kiwigrid/k8s-sidecar
  ingress:
    enabled: true
    annotations:
      kubernetes.io/ingress.class: "nginx"
      nginx.ingress.kubernetes.io/rewrite-target: /$1
      nginx.ingress.kubernetes.io/use-regex: "true"
    path: /grafana/?(.*)
    hosts: [<hosts>]
  grafana.ini:
    server:
      root_url: http://localhost:3000/grafana
  persistence:
    enabled: true
    existingClaim: grafana
  initChownData:
    enabled: false
    # image:
    #   repository: busybox

# prometheus-node-exporter:
#   serviceAccount:
#     imagePullSecrets:
#   image:
#     repository: quay.io/prometheus/node-exporter
# kube-state-metrics:
#   image:
#     repository: quay.io/coreos/kube-state-metrics'''


yaml = '''# image:
#   repository: kubernetesui/dashboard
protocolHttp: true
rbac:
  create: true
  clusterRoleMetrics: true
serviceAccount:
  create: false
  name: th2infra-kubernetes-dashboard 
ingress:
  enabled: true
  annotations:
    kubernetes.io/ingress.class: "nginx"
    nginx.ingress.kubernetes.io/rewrite-target: $1
    nginx.ingress.kubernetes.io/configuration-snippet: rewrite ^/([a-z\-0-9]*)$ $scheme://$http_host/$1/ redirect;
  paths:
    - /dashboard($|/.*)
  hosts: [<hosts>]'''


yaml = '''imagePullSecrets:
controller:
  service:
    type: NodePort
    nodePorts:
      http: 30000
  # image:
  #   repository: k8s.gcr.io/ingress-nginx/controller
  #   tag: "v0.41.2"
  admissionWebhooks:
    enabled: false
# defaultBackend:
#   image:
#     repository: defaultbackend-amd64
#     tag: "1.5"'''


yaml = '''---
apiVersion: v1
kind: PersistentVolume
metadata:
  name: storage-loki
  labels:
    app: loki
spec:
  capacity:
    storage: 5Gi
  volumeMode: Filesystem
  accessModes:
    - ReadWriteOnce
  persistentVolumeReclaimPolicy: Retain
  storageClassName: local-storage
  local:
    path: /opt/loki
  nodeAffinity:
    required:
      nodeSelectorTerms:
        - matchExpressions:
            - key: kubernetes.io/hostname
              operator: In
              values:
                - <node-name>
---
apiVersion: v1
kind: PersistentVolume
metadata:
  name: storage-grafana
  labels:
    app: grafana
spec:
  capacity:
    storage: 1Gi
  volumeMode: Filesystem
  accessModes:
    - ReadWriteOnce
  persistentVolumeReclaimPolicy: Retain
  storageClassName: local-storage
  local:
    path: /opt/grafana
  nodeAffinity:
    required:
      nodeSelectorTerms:
        - matchExpressions:
            - key: kubernetes.io/hostname
              operator: In
              values:
                - <node-name>
---
apiVersion: v1
kind: PersistentVolume
metadata:
  name: storage-prometheus
  labels:
    app: prometheus
    prometheus: prometheus-kube-prometheus-prometheus
spec:
  capacity:
    storage: 5Gi
  volumeMode: Filesystem
  accessModes:
    - ReadWriteOnce
  persistentVolumeReclaimPolicy: Retain
  local:
    path: /opt/prometheus
  nodeAffinity:
    required:
      nodeSelectorTerms:
        - matchExpressions:
            - key: kubernetes.io/hostname
              operator: In
              values:
                - <node-name>
---
apiVersion: v1
kind: PersistentVolume
metadata:
  name: storage-rabbitmq
  namespace: service
  labels:
    app: rabbitmq
spec:
  capacity:
    storage: 10Gi
  volumeMode: Filesystem
  accessModes:
    - ReadWriteOnce
  persistentVolumeReclaimPolicy: Retain
  storageClassName: local-storage
  local:
    path: /opt/rabbitmq
  nodeAffinity:
    required:
      nodeSelectorTerms:
        - matchExpressions:
            - key: kubernetes.io/hostname
              operator: In
              values:
                - <node-name>
---
#if you neeed to deploy onfra-git
#apiVersion: v1
#kind: PersistentVolume
#metadata:
#  name: repos-volume
#  labels:
#    app: repos-volume
#spec:
#  capacity:
#    storage: 5Gi
#  volumeMode: Filesystem
#  accessModes:
#    - ReadWriteMany
#  persistentVolumeReclaimPolicy: Retain
#  storageClassName: local-storage
#  local:
#    path: /opt/git
#  nodeAffinity:
#    required:
#      nodeSelectorTerms:
#        - matchExpressions:
#            - key: kubernetes.io/hostname
#              operator: In
#              values:
#                - <node-name>'''



from th2_cli.cli.install import install

import signal


def handler(signum, frame):
    print("Ctrl-C was pressed. Exiting ")
    exit(1)


class Th2Cli:
    def install(self):
        signal.signal(signal.SIGINT, handler)
        install()



from cryptography.hazmat.primitives import serialization as crypto_serialization
from cryptography.hazmat.primitives.asymmetric import rsa
from cryptography.hazmat.backends import default_backend as crypto_default_backend
from typing import Tuple


def generate_ssh_keys() -> Tuple[str, str]:
    key = rsa.generate_private_key(
        backend=crypto_default_backend(),
        public_exponent=65537,
        key_size=2048
    )

    private_key = key.private_bytes(
        crypto_serialization.Encoding.PEM,
        crypto_serialization.PrivateFormat.PKCS8,
        crypto_serialization.NoEncryption()
    )

    public_key = key.public_key().public_bytes(
        crypto_serialization.Encoding.OpenSSH,
        crypto_serialization.PublicFormat.OpenSSH
    )
    return private_key.decode('utf-8'), public_key.decode('utf-8')



from kubernetes.client import ApiClient, CoreV1Api, V1Namespace
from kubernetes.utils import create_from_yaml
from colorama import Fore, Style, Back
from simple_term_menu import TerminalMenu
from typing import Iterator

from th2_cli.utils.kubernetes import create_namespace_object, get_nodes
from th2_cli.utils import get_yaml_config, print_error


def preinstall_warning():
    print(f'{Fore.YELLOW}Before th2 installation you should fulfill following prerequisites:')
    print(f'  1. You should have {Fore.CYAN}Kubernetes cluster{Fore.YELLOW} deployed {Fore.RED}(v1.19 - 1.20){Fore.YELLOW};')
    print(f'    1.1. You should have {Fore.CYAN}kubectl{Fore.YELLOW} installed and configured with {Fore.RED}k8s admin '
          f'profile{Fore.YELLOW};')
    print(f'  2. You should have {Fore.CYAN}Cassandra database{Fore.YELLOW} deployed {Fore.RED}(v3.11.6+){Fore.YELLOW}.{Style.RESET_ALL}')
    proceed = input(f'Proceed to th2 installation ({Fore.YELLOW}y/N{Style.RESET_ALL}): ')
    if proceed.lower() != 'y':
        print(f'{Fore.YELLOW}Cancelling installation...{Style.RESET_ALL}')
        exit(1)


def pv_folders_warning():
    print(f'{Fore.YELLOW}Be sure that you have created folders on the chosen node:')
    print(f'{Style.BRIGHT}mkdir /opt/grafana /opt/prometheus /opt/loki /opt/rabbitmq{Style.RESET_ALL}')
    input(f'Press {Back.YELLOW}Enter{Style.RESET_ALL} to continue')


def create_namespace(k8s_core: CoreV1Api, name: str):
    try:
        k8s_core.create_namespace(create_namespace_object(name))
        print(f'"{name}" namespace created')
    except:
        print_error(f'"{name}" namespace already exist')


def install_flannel(k8s_client: ApiClient):
    try:
        flannel_manifest = get_yaml_config(
            "https://raw.githubusercontent.com/flannel-io/flannel/master/Documentation/kube-flannel.yml")
        create_from_yaml(k8s_client=k8s_client, yaml_objects=flannel_manifest)
        print(f'flannel-cni is installed')
    except:
        print_error(f"Error while installing flannel. It might already exist")


def choose_node(k8s_core: CoreV1Api) -> str:
    nodes = get_nodes(k8s_core)
    terminal_menu = TerminalMenu(nodes, title='Kubernetes nodes:')
    node_index = terminal_menu.show()
    chosen_node = nodes[node_index]
    return chosen_node


def apply_yaml(k8s_client: ApiClient, yaml_obj: Iterator[dict], file_name: str = 'undefined'):
    try:
        create_from_yaml(k8s_client=k8s_client, yaml_objects=yaml_obj)
    except:
        print_error(f'Error while applying "{file_name}"')



yaml = '''loki:
  # image:
  #   pullPolicy: IfNotPresent
  #   repository: grafana/loki
  #   pullSecrets:
  persistence:
    enabled: true
    existingClaim: loki
  config:
    table_manager:
      retention_deletes_enabled: true
      retention_period: 168h
    chunk_store_config:
      max_look_back_period: 168h

promtail:
#   image:
#     pullPolicy: IfNotPresent
#     repository: grafana/promtail
#     pullSecrets:
  resources:
    limits:
      cpu: 500m
      memory: 400Mi
    requests:
      cpu: 200m
      memory: 200Mi'''



yaml = '''infraMgr:
  git:
    repository: <repository>
    httpAuthUsername: <username>
    httpAuthPassword: <password>

rabbitmq:
  prometheus:
    operator:
      enabled: false
  persistentVolume:
    enabled: true
    storageClass: local-storage
    size: 10Gi
    
externalRabbitMQHost:
  host: <host>

cassandra:
  internal: false
  host: <cassandra-host>
  cluster:
    datacenter: <datacenter>'''



yaml = '''---
apiVersion: v1
kind: PersistentVolumeClaim
metadata:
  name: loki
  namespace: monitoring
spec:
  accessModes:
    - ReadWriteOnce
  volumeMode: Filesystem
  resources:
    requests:
      storage: 5Gi
  storageClassName: local-storage
  selector:
    matchLabels:
      app: "loki"
---
apiVersion: v1
kind: PersistentVolumeClaim
metadata:
  name: grafana
  namespace: monitoring
spec:
  accessModes:
    - ReadWriteOnce
  volumeMode: Filesystem
  resources:
    requests:
      storage: 1Gi
  storageClassName: local-storage
  selector:
    matchLabels:
      app: "grafana"'''



from cassandra.cluster import Cluster
from typing import List
from simple_term_menu import TerminalMenu
from th2_cli.utils import print_error, read_value
from cassandra.auth import PlainTextAuthProvider


def get_datacenters(host: str) -> List[str]:
    host = read_value('Enter host for connecting to Cassandra', 'Cassandra host', host)
    auth = PlainTextAuthProvider(
        username=read_value('Enter cassandra admin username', 'username', 'cassandra'),
        password=read_value('Enter cassandra admin password', 'password', 'cassandra')
    )
    cluster = Cluster([host], auth_provider=auth)
    try:
        session = cluster.connect('system')
    except:
        print_error('Cassandra cluster is unavailable')
        raise
    datacenters = list(map(lambda row: row.data_center, session.execute('select data_center from local;')))
    return datacenters


def choose_datacenter(host: str) -> str:
    datacenters = get_datacenters(host)
    terminal_menu = TerminalMenu(datacenters, title='Choose Cassandra datacenter:')
    node_index = terminal_menu.show()
    chosen_dc = datacenters[node_index]
    return chosen_dc



from kubernetes.client import ApiClient, CoreV1Api, V1Namespace
from kubernetes import client, config
from urllib.parse import urlparse
from typing import Tuple, List
from th2_cli.utils import print_error


def connect() -> Tuple[ApiClient, CoreV1Api]:
    config.load_kube_config()
    k8s_client = client.ApiClient()
    k8s_core = client.CoreV1Api()
    return k8s_client, k8s_core


def create_namespace_object(name: str) -> V1Namespace:
    return V1Namespace(metadata=client.V1ObjectMeta(name=name))


def get_namespaces(k8s_core: CoreV1Api) -> List[str]:
    namespaces = list(
        map(lambda item: item.metadata.name, k8s_core.list_namespace().items)
    )
    return namespaces


def get_nodes(k8s_core: CoreV1Api) -> List[str]:
    nodes = list(
        map(lambda item: item.metadata.name, k8s_core.list_node().items)
    )
    return nodes


def get_cluster_host(k8s_client: ApiClient) -> str:
    url = k8s_client.configuration.host
    return urlparse(url).netloc.split(':')[0]


def create_secret(k8s_core: CoreV1Api, name: str, data: dict = None, string_data: dict = None,
                  namespace: str = 'service'):
    try:
        secret = client.V1Secret(
            metadata=client.V1ObjectMeta(name=name),
            data=data,
            string_data=string_data
        )
        k8s_core.create_namespaced_secret(namespace=namespace,
                                          body=secret)
    except:
        print_error(f'Failed to create "{name}" secret')




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['th2_cli',
 'th2_cli.cli',
 'th2_cli.templates',
 'th2_cli.templates.install',
 'th2_cli.templates.install.values',
 'th2_cli.utils',
 'th2_cli.utils.helm']

package_data = \
{'': ['*']}

install_requires = \
['avionix>=0.4.5,<0.5.0',
 'cassandra-driver>=3.25.0,<4.0.0',
 'colorama>=0.4.5,<0.5.0',
 'cryptography>=37.0.4,<38.0.0',
 'fire>=0.4.0,<0.5.0',
 'kubernetes>=24.2.0,<25.0.0',
 'requests>=2.28.1,<3.0.0',
 'simple-term-menu>=1.5.0,<2.0.0',
 'urllib3>=1.26.12,<2.0.0']

entry_points = \
{'console_scripts': ['th2 = th2_cli:cli']}

setup_kwargs = {
    'name': 'th2-cli',
    'version': '0.2.2',
    'description': '👨\u200d💻 CLI for managing th2 infrastructure in Kubernetes cluster',
    'long_description': '## Using\n\nInstall:\n\n```commandline\npip install th2-cli\n```\n\nRun:\n\n```commandline\nth2 install\n```\n\n## Development\n\n```\npoetry install\npoetry shell\n```\n\n```commandline\nth2 install\n```',
    'author': 'Nikolay Dorofeev',
    'author_email': 'dorich2000@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
